@@ -22,7 +22,9 @@ typedef enum
                                                   */
   ELM_GENGRID_ITEM_SCROLLTO_TOP = 2 /* 1 << 1 */, /** To the top of viewport.
                                                    */
-  ELM_GENGRID_ITEM_SCROLLTO_MIDDLE = 4 /* 1 << 2 */ /** To the middle of
+  ELM_GENGRID_ITEM_SCROLLTO_MIDDLE = 4 /* 1 << 2 */, /** To the middle of
+                                                      * viewport. */
+  ELM_GENGRID_ITEM_SCROLLTO_BOTTOM = 8 /* 1 << 3 */ /** To the bottom of
                                                      * viewport. */
 } Elm_Gengrid_Item_Scrollto_Type;
 
@@ -55,7 +57,7 @@ EAPI const Eo_Class *elm_gengrid_item_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_item_prev_get(void);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_item_prev_get(void);
 
 /**
  * @brief Get the next item in a gengrid widget's internal list of items, given
@@ -67,7 +69,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_item_prev_get(void);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI Elm_Widget_Item * elm_obj_gengrid_item_next_get(void);
+EOAPI Elm_Widget_Item *elm_obj_gengrid_item_next_get(void);
 
 /**
  * @brief Control whether a given gengrid item is selected or not
@@ -84,7 +86,7 @@ EOAPI Elm_Widget_Item * elm_obj_gengrid_item_next_get(void);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_selected_set(Eina_Bool selected);
+EOAPI void elm_obj_gengrid_item_selected_set(Eina_Bool selected);
 
 /**
  * @brief Control whether a given gengrid item is selected or not
@@ -100,7 +102,7 @@ EOAPI void  elm_obj_gengrid_item_selected_set(Eina_Bool selected);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI Eina_Bool  elm_obj_gengrid_item_selected_get(void);
+EOAPI Eina_Bool elm_obj_gengrid_item_selected_get(void);
 
 /**
  * @brief Get the Gengrid Item class for the given Gengrid Item.
@@ -112,7 +114,7 @@ EOAPI Eina_Bool  elm_obj_gengrid_item_selected_get(void);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI const Elm_Gengrid_Item_Class * elm_obj_gengrid_item_class_get(void);
+EOAPI const Elm_Gengrid_Item_Class *elm_obj_gengrid_item_class_get(void);
 
 /**
  * @brief Get the index of the item. It is only valid once displayed.
@@ -121,7 +123,7 @@ EOAPI const Elm_Gengrid_Item_Class * elm_obj_gengrid_item_class_get(void);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI int  elm_obj_gengrid_item_index_get(void);
+EOAPI int elm_obj_gengrid_item_index_get(void);
 
 /**
  * @brief Get a given gengrid item's position, relative to the whole gengrid's
@@ -135,7 +137,7 @@ EOAPI int  elm_obj_gengrid_item_index_get(void);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_pos_get(unsigned int *x, unsigned int *y);
+EOAPI void elm_obj_gengrid_item_pos_get(unsigned int *x, unsigned int *y);
 
 /**
  * @brief Control the gengrid item's select mode.
@@ -160,7 +162,7 @@ EOAPI void  elm_obj_gengrid_item_pos_get(unsigned int *x, unsigned int *y);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_select_mode_set(Elm_Object_Select_Mode mode);
+EOAPI void elm_obj_gengrid_item_select_mode_set(Elm_Object_Select_Mode mode);
 
 /**
  * @brief Control the gengrid item's select mode.
@@ -185,7 +187,7 @@ EOAPI void  elm_obj_gengrid_item_select_mode_set(Elm_Object_Select_Mode mode);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI Elm_Object_Select_Mode  elm_obj_gengrid_item_select_mode_get(void);
+EOAPI Elm_Object_Select_Mode elm_obj_gengrid_item_select_mode_get(void);
 
 /**
  * @brief Show the portion of a gengrid's internal grid containing a given
@@ -198,7 +200,7 @@ EOAPI Elm_Object_Select_Mode  elm_obj_gengrid_item_select_mode_get(void);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_show(Elm_Gengrid_Item_Scrollto_Type type);
+EOAPI void elm_obj_gengrid_item_show(Elm_Gengrid_Item_Scrollto_Type type);
 
 /**
  * @brief Animatedly bring in, to the visible area of a gengrid, a given item
@@ -212,7 +214,7 @@ EOAPI void  elm_obj_gengrid_item_show(Elm_Gengrid_Item_Scrollto_Type type);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_bring_in(Elm_Gengrid_Item_Scrollto_Type type);
+EOAPI void elm_obj_gengrid_item_bring_in(Elm_Gengrid_Item_Scrollto_Type type);
 
 /**
  * @brief Update the contents of a given gengrid item
@@ -223,7 +225,7 @@ EOAPI void  elm_obj_gengrid_item_bring_in(Elm_Gengrid_Item_Scrollto_Type type);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_update(void);
+EOAPI void elm_obj_gengrid_item_update(void);
 
 /**
  * @brief Update the part of an item
@@ -242,7 +244,7 @@ EOAPI void  elm_obj_gengrid_item_update(void);
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_fields_update(const char *parts, Elm_Gengrid_Item_Field_Type itf);
+EOAPI void elm_obj_gengrid_item_fields_update(const char *parts, Elm_Gengrid_Item_Field_Type itf);
 
 /**
  * @brief Update the item class of a gengrid item.
@@ -256,7 +258,7 @@ EOAPI void  elm_obj_gengrid_item_fields_update(const char *parts, Elm_Gengrid_It
  *
  * @ingroup Elm_Gengrid_Item
  */
-EOAPI void  elm_obj_gengrid_item_class_update(const Elm_Gengrid_Item_Class *itc);
+EOAPI void elm_obj_gengrid_item_class_update(const Elm_Gengrid_Item_Class *itc);
 
 
 #endif
