@@ -22,7 +22,9 @@ typedef enum
                                                   */
   ELM_GENGRID_ITEM_SCROLLTO_TOP = 2 /* 1 << 1 */, /** To the top of viewport.
                                                    */
-  ELM_GENGRID_ITEM_SCROLLTO_MIDDLE = 4 /* 1 << 2 */ /** To the middle of
+  ELM_GENGRID_ITEM_SCROLLTO_MIDDLE = 4 /* 1 << 2 */, /** To the middle of
+                                                      * viewport. */
+  ELM_GENGRID_ITEM_SCROLLTO_BOTTOM = 8 /* 1 << 3 */ /** To the bottom of
                                                      * viewport. */
 } Elm_Gengrid_Item_Scrollto_Type;
 
