@@ -35,7 +35,7 @@ EAPI const Eo_Class *elm_genlist_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_homogeneous_set(Eina_Bool homogeneous);
+EOAPI void elm_obj_genlist_homogeneous_set(Eina_Bool homogeneous);
 
 /**
  * @brief Get whether the homogeneous mode is enabled.
@@ -45,7 +45,7 @@ EOAPI void  elm_obj_genlist_homogeneous_set(Eina_Bool homogeneous);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Bool  elm_obj_genlist_homogeneous_get(void);
+EOAPI Eina_Bool elm_obj_genlist_homogeneous_get(void);
 
 /**
  * @brief Set the genlist select mode.
@@ -62,7 +62,7 @@ EOAPI Eina_Bool  elm_obj_genlist_homogeneous_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_select_mode_set(Elm_Object_Select_Mode mode);
+EOAPI void elm_obj_genlist_select_mode_set(Elm_Object_Select_Mode mode);
 
 /**
  * @brief Get the genlist select mode.
@@ -71,7 +71,7 @@ EOAPI void  elm_obj_genlist_select_mode_set(Elm_Object_Select_Mode mode);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Object_Select_Mode  elm_obj_genlist_select_mode_get(void);
+EOAPI Elm_Object_Select_Mode elm_obj_genlist_select_mode_get(void);
 
 /**
  * @brief Set focus upon items selection mode
@@ -86,7 +86,7 @@ EOAPI Elm_Object_Select_Mode  elm_obj_genlist_select_mode_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_focus_on_selection_set(Eina_Bool enabled);
+EOAPI void elm_obj_genlist_focus_on_selection_set(Eina_Bool enabled);
 
 /**
  * @brief Get whether focus upon item's selection mode is enabled.
@@ -95,7 +95,7 @@ EOAPI void  elm_obj_genlist_focus_on_selection_set(Eina_Bool enabled);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Bool  elm_obj_genlist_focus_on_selection_get(void);
+EOAPI Eina_Bool elm_obj_genlist_focus_on_selection_get(void);
 
 /**
  * @brief Set the timeout in seconds for the longpress event.
@@ -112,7 +112,7 @@ EOAPI Eina_Bool  elm_obj_genlist_focus_on_selection_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_longpress_timeout_set(double timeout);
+EOAPI void elm_obj_genlist_longpress_timeout_set(double timeout);
 
 /**
  * @brief Get the timeout in seconds for the longpress event.
@@ -121,7 +121,7 @@ EOAPI void  elm_obj_genlist_longpress_timeout_set(double timeout);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI double  elm_obj_genlist_longpress_timeout_get(void);
+EOAPI double elm_obj_genlist_longpress_timeout_get(void);
 
 /**
  * @brief Enable or disable multi-selection in the genlist.
@@ -134,7 +134,7 @@ EOAPI double  elm_obj_genlist_longpress_timeout_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_multi_select_set(Eina_Bool multi);
+EOAPI void elm_obj_genlist_multi_select_set(Eina_Bool multi);
 
 /**
  * @brief Get if multi-selection in genlist is enabled or disabled.
@@ -143,7 +143,7 @@ EOAPI void  elm_obj_genlist_multi_select_set(Eina_Bool multi);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Bool  elm_obj_genlist_multi_select_get(void);
+EOAPI Eina_Bool elm_obj_genlist_multi_select_get(void);
 
 /**
  * @brief Set reorder mode.
@@ -156,7 +156,7 @@ EOAPI Eina_Bool  elm_obj_genlist_multi_select_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_reorder_mode_set(Eina_Bool reorder_mode);
+EOAPI void elm_obj_genlist_reorder_mode_set(Eina_Bool reorder_mode);
 
 /**
  * @brief Get the reorder mode.
@@ -165,7 +165,7 @@ EOAPI void  elm_obj_genlist_reorder_mode_set(Eina_Bool reorder_mode);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Bool  elm_obj_genlist_reorder_mode_get(void);
+EOAPI Eina_Bool elm_obj_genlist_reorder_mode_get(void);
 
 /**
  * @brief Set Genlist decorate mode.
@@ -176,7 +176,7 @@ EOAPI Eina_Bool  elm_obj_genlist_reorder_mode_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_decorate_mode_set(Eina_Bool decorated);
+EOAPI void elm_obj_genlist_decorate_mode_set(Eina_Bool decorated);
 
 /**
  * @brief Get Genlist decorate mode.
@@ -185,7 +185,7 @@ EOAPI void  elm_obj_genlist_decorate_mode_set(Eina_Bool decorated);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Bool  elm_obj_genlist_decorate_mode_get(void);
+EOAPI Eina_Bool elm_obj_genlist_decorate_mode_get(void);
 
 /**
  * @brief Set the genlist multi select mode.
@@ -202,7 +202,7 @@ EOAPI Eina_Bool  elm_obj_genlist_decorate_mode_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_multi_select_mode_set(Elm_Object_Multi_Select_Mode mode);
+EOAPI void elm_obj_genlist_multi_select_mode_set(Elm_Object_Multi_Select_Mode mode);
 
 /**
  * @brief Get the genlist multi select mode.
@@ -213,7 +213,7 @@ EOAPI void  elm_obj_genlist_multi_select_mode_set(Elm_Object_Multi_Select_Mode m
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Object_Multi_Select_Mode  elm_obj_genlist_multi_select_mode_get(void);
+EOAPI Elm_Object_Multi_Select_Mode elm_obj_genlist_multi_select_mode_get(void);
 
 /**
  * @brief Set the maximum number of items within an item block.
@@ -235,7 +235,7 @@ EOAPI Elm_Object_Multi_Select_Mode  elm_obj_genlist_multi_select_mode_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_block_count_set(int count);
+EOAPI void elm_obj_genlist_block_count_set(int count);
 
 /**
  * @brief Get the maximum number of items within an item block.
@@ -244,7 +244,7 @@ EOAPI void  elm_obj_genlist_block_count_set(int count);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI int  elm_obj_genlist_block_count_get(void);
+EOAPI int elm_obj_genlist_block_count_get(void);
 
 /**
  * @brief Control genlist tree effect.
@@ -253,7 +253,7 @@ EOAPI int  elm_obj_genlist_block_count_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_tree_effect_enabled_set(Eina_Bool enabled);
+EOAPI void elm_obj_genlist_tree_effect_enabled_set(Eina_Bool enabled);
 
 /**
  * @brief Control genlist tree effect.
@@ -262,7 +262,7 @@ EOAPI void  elm_obj_genlist_tree_effect_enabled_set(Eina_Bool enabled);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Bool  elm_obj_genlist_tree_effect_enabled_get(void);
+EOAPI Eina_Bool elm_obj_genlist_tree_effect_enabled_get(void);
 
 /**
  * @brief Set whether the genlist items should be highlighted on item
@@ -278,7 +278,7 @@ EOAPI Eina_Bool  elm_obj_genlist_tree_effect_enabled_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_highlight_mode_set(Eina_Bool highlight);
+EOAPI void elm_obj_genlist_highlight_mode_set(Eina_Bool highlight);
 
 /**
  * @brief Get whether the genlist items' should be highlighted when item
@@ -288,7 +288,7 @@ EOAPI void  elm_obj_genlist_highlight_mode_set(Eina_Bool highlight);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Bool  elm_obj_genlist_highlight_mode_get(void);
+EOAPI Eina_Bool elm_obj_genlist_highlight_mode_get(void);
 
 /**
  * @brief This sets the horizontal stretching mode.
@@ -318,7 +318,7 @@ EOAPI Eina_Bool  elm_obj_genlist_highlight_mode_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_mode_set(Elm_List_Mode mode);
+EOAPI void elm_obj_genlist_mode_set(Elm_List_Mode mode);
 
 /**
  * @brief Get the horizontal stretching mode.
@@ -327,7 +327,7 @@ EOAPI void  elm_obj_genlist_mode_set(Elm_List_Mode mode);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_List_Mode  elm_obj_genlist_mode_get(void);
+EOAPI Elm_List_Mode elm_obj_genlist_mode_get(void);
 
 /**
  * @brief Get active genlist mode item.
@@ -340,7 +340,7 @@ EOAPI Elm_List_Mode  elm_obj_genlist_mode_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_decorated_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_genlist_decorated_item_get(void);
 
 /**
  * @brief Get the selected item in the genlist.
@@ -356,18 +356,20 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_decorated_item_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_selected_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_genlist_selected_item_get(void);
 
 /**
  * @brief Get the first item in the genlist.
  *
  * This returns the first item in the list.
  *
+ * If filter is set on genlist, it returns the first filtered item in the list.
+ *
  * @return The first item or @c null.
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_first_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_genlist_first_item_get(void);
 
 /**
  * @brief Get a list of realized items in genlist.
@@ -379,7 +381,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_first_item_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_List * elm_obj_genlist_realized_items_get(void);
+EOAPI Eina_List *elm_obj_genlist_realized_items_get(void);
 
 /**
  * @brief Get a list of selected items in the genlist.
@@ -396,16 +398,18 @@ EOAPI Eina_List * elm_obj_genlist_realized_items_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI const Eina_List * elm_obj_genlist_selected_items_get(void);
+EOAPI const Eina_List *elm_obj_genlist_selected_items_get(void);
 
 /**
  * @brief Get the last item in the genlist
  *
  * This returns the last item in the list.
  *
+ * If filter is set to genlist, it returns last filtered item in the list.
+ *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_last_item_get(void);
+EOAPI Elm_Widget_Item *elm_obj_genlist_last_item_get(void);
 
 /**
  * @brief Set filter mode with key.
@@ -420,7 +424,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_last_item_get(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_filter_set(void *key);
+EOAPI void elm_obj_genlist_filter_set(void *key);
 
 /**
  * @brief Insert an item before another in a genlist widget
@@ -437,7 +441,7 @@ EOAPI void  elm_obj_genlist_filter_set(void *key);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_insert_before(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Widget_Item *before_it, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_insert_before(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Widget_Item *before_it, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Update the contents of all realized items.
@@ -450,7 +454,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_insert_before(const Elm_Genlist_Ite
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_realized_items_update(void);
+EOAPI void elm_obj_genlist_realized_items_update(void);
 
 /**
  * @brief Insert an item after another in a genlist widget
@@ -467,7 +471,7 @@ EOAPI void  elm_obj_genlist_realized_items_update(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_insert_after(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Widget_Item *after_it, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_insert_after(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Widget_Item *after_it, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Get the item that is at the x, y canvas coords.
@@ -486,7 +490,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_insert_after(const Elm_Genlist_Item
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_at_xy_item_get(Evas_Coord x, Evas_Coord y, int *posret);
+EOAPI Elm_Widget_Item *elm_obj_genlist_at_xy_item_get(Evas_Coord x, Evas_Coord y, int *posret);
 
 /**
  * @brief Returns an iterator over the list of filtered items.
@@ -498,7 +502,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_at_xy_item_get(Evas_Coord x, Evas_Coord
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Eina_Iterator * elm_obj_genlist_filter_iterator_new(void);
+EOAPI Eina_Iterator *elm_obj_genlist_filter_iterator_new(void);
 
 /**
  * @brief Return how many items are currently in a list.
@@ -507,7 +511,7 @@ EOAPI Eina_Iterator * elm_obj_genlist_filter_iterator_new(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI unsigned int  elm_obj_genlist_items_count(void);
+EOAPI unsigned int elm_obj_genlist_items_count(void);
 
 /**
  * @brief Prepend a new item in a given genlist widget.
@@ -523,7 +527,7 @@ EOAPI unsigned int  elm_obj_genlist_items_count(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_prepend(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_prepend(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Remove all items from a given genlist widget.
@@ -532,7 +536,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_prepend(const Elm_Genlist_Item_Clas
  *
  * @ingroup Elm_Genlist
  */
-EOAPI void  elm_obj_genlist_clear(void);
+EOAPI void elm_obj_genlist_clear(void);
 
 /**
  * @brief Append a new item in a given genlist widget.
@@ -548,7 +552,7 @@ EOAPI void  elm_obj_genlist_clear(void);
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_append(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_append(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Genlist_Item_Type type, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Insert a new item into the sorted genlist object
@@ -566,7 +570,7 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_append(const Elm_Genlist_Item_Class
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_item_sorted_insert(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Genlist_Item_Type type, Eina_Compare_Cb comp, Evas_Smart_Cb func, const void *func_data);
+EOAPI Elm_Widget_Item *elm_obj_genlist_item_sorted_insert(const Elm_Genlist_Item_Class *itc, const void *data, Elm_Widget_Item *parent, Elm_Genlist_Item_Type type, Eina_Compare_Cb comp, Evas_Smart_Cb func, const void *func_data);
 
 /**
  * @brief Get genlist item by given string.
@@ -587,10 +591,8 @@ EOAPI Elm_Widget_Item * elm_obj_genlist_item_sorted_insert(const Elm_Genlist_Ite
  *
  * @ingroup Elm_Genlist
  */
-EOAPI Elm_Widget_Item * elm_obj_genlist_search_by_text_item_get(Elm_Widget_Item *item_to_search_from, const char *part_name, const char *pattern, Elm_Glob_Match_Flags flags);
+EOAPI Elm_Widget_Item *elm_obj_genlist_search_by_text_item_get(Elm_Widget_Item *item_to_search_from, const char *part_name, const char *pattern, Elm_Glob_Match_Flags flags);
 
-EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_ACCESS_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_ITEM_FOCUSED;
 EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_ITEM_UNFOCUSED;
 EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_VBAR_DRAG;
@@ -627,16 +629,6 @@ EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_INDEX_UPDATE;
 EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_TREE_EFFECT_FINISHED;
 EOAPI extern const Eo_Event_Description _ELM_GENLIST_EVENT_FILTER_DONE;
 
-/**
- * No description
- */
-#define ELM_GENLIST_EVENT_LANGUAGE_CHANGED (&(_ELM_GENLIST_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_GENLIST_EVENT_ACCESS_CHANGED (&(_ELM_GENLIST_EVENT_ACCESS_CHANGED))
-
 /**
  * No description
  */
