@@ -40,7 +40,7 @@ EAPI const Eo_Class *elm_label_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Label
  */
-EOAPI void  elm_obj_label_wrap_width_set(Evas_Coord w);
+EOAPI void elm_obj_label_wrap_width_set(Evas_Coord w);
 
 /**
  * @brief Control wrap width of the label
@@ -53,7 +53,7 @@ EOAPI void  elm_obj_label_wrap_width_set(Evas_Coord w);
  *
  * @ingroup Elm_Label
  */
-EOAPI Evas_Coord  elm_obj_label_wrap_width_get(void);
+EOAPI Evas_Coord elm_obj_label_wrap_width_get(void);
 
 /**
  * @brief Control the slide speed of the label
@@ -68,7 +68,7 @@ EOAPI Evas_Coord  elm_obj_label_wrap_width_get(void);
  *
  * @ingroup Elm_Label
  */
-EOAPI void  elm_obj_label_slide_speed_set(double speed);
+EOAPI void elm_obj_label_slide_speed_set(double speed);
 
 /**
  * @brief Control the slide speed of the label
@@ -83,7 +83,7 @@ EOAPI void  elm_obj_label_slide_speed_set(double speed);
  *
  * @ingroup Elm_Label
  */
-EOAPI double  elm_obj_label_slide_speed_get(void);
+EOAPI double elm_obj_label_slide_speed_get(void);
 
 /**
  * @brief Control the slide mode of the label widget.
@@ -108,7 +108,7 @@ EOAPI double  elm_obj_label_slide_speed_get(void);
  *
  * @ingroup Elm_Label
  */
-EOAPI void  elm_obj_label_slide_mode_set(Elm_Label_Slide_Mode mode);
+EOAPI void elm_obj_label_slide_mode_set(Elm_Label_Slide_Mode mode);
 
 /**
  * @brief Control the slide mode of the label widget.
@@ -133,7 +133,7 @@ EOAPI void  elm_obj_label_slide_mode_set(Elm_Label_Slide_Mode mode);
  *
  * @ingroup Elm_Label
  */
-EOAPI Elm_Label_Slide_Mode  elm_obj_label_slide_mode_get(void);
+EOAPI Elm_Label_Slide_Mode elm_obj_label_slide_mode_get(void);
 
 /**
  * @brief Control the slide duration of the label
@@ -147,7 +147,7 @@ EOAPI Elm_Label_Slide_Mode  elm_obj_label_slide_mode_get(void);
  *
  * @ingroup Elm_Label
  */
-EOAPI void  elm_obj_label_slide_duration_set(double duration);
+EOAPI void elm_obj_label_slide_duration_set(double duration);
 
 /**
  * @brief Control the slide duration of the label
@@ -161,7 +161,7 @@ EOAPI void  elm_obj_label_slide_duration_set(double duration);
  *
  * @ingroup Elm_Label
  */
-EOAPI double  elm_obj_label_slide_duration_get(void);
+EOAPI double elm_obj_label_slide_duration_get(void);
 
 /**
  * @brief Control the wrapping behavior of the label
@@ -175,7 +175,7 @@ EOAPI double  elm_obj_label_slide_duration_get(void);
  *
  * @ingroup Elm_Label
  */
-EOAPI void  elm_obj_label_line_wrap_set(Elm_Wrap_Type wrap);
+EOAPI void elm_obj_label_line_wrap_set(Elm_Wrap_Type wrap);
 
 /**
  * @brief Control the wrapping behavior of the label
@@ -189,7 +189,7 @@ EOAPI void  elm_obj_label_line_wrap_set(Elm_Wrap_Type wrap);
  *
  * @ingroup Elm_Label
  */
-EOAPI Elm_Wrap_Type  elm_obj_label_line_wrap_get(void);
+EOAPI Elm_Wrap_Type elm_obj_label_line_wrap_get(void);
 
 /**
  * @brief Control the ellipsis behavior of the label
@@ -204,7 +204,7 @@ EOAPI Elm_Wrap_Type  elm_obj_label_line_wrap_get(void);
  *
  * @ingroup Elm_Label
  */
-EOAPI void  elm_obj_label_ellipsis_set(Eina_Bool ellipsis);
+EOAPI void elm_obj_label_ellipsis_set(Eina_Bool ellipsis);
 
 /**
  * @brief Control the ellipsis behavior of the label
@@ -219,7 +219,7 @@ EOAPI void  elm_obj_label_ellipsis_set(Eina_Bool ellipsis);
  *
  * @ingroup Elm_Label
  */
-EOAPI Eina_Bool  elm_obj_label_ellipsis_get(void);
+EOAPI Eina_Bool elm_obj_label_ellipsis_get(void);
 
 /**
  * @brief Start slide effect.
@@ -228,22 +228,10 @@ EOAPI Eina_Bool  elm_obj_label_ellipsis_get(void);
  *
  * @ingroup Elm_Label
  */
-EOAPI void  elm_obj_label_slide_go(void);
+EOAPI void elm_obj_label_slide_go(void);
 
-EOAPI extern const Eo_Event_Description _ELM_LABEL_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_LABEL_EVENT_ACCESS_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_LABEL_EVENT_SLIDE_END;
 
-/**
- * No description
- */
-#define ELM_LABEL_EVENT_LANGUAGE_CHANGED (&(_ELM_LABEL_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_LABEL_EVENT_ACCESS_CHANGED (&(_ELM_LABEL_EVENT_ACCESS_CHANGED))
-
 /**
  * No description
  */
