@@ -35,7 +35,7 @@ EAPI const Eo_Class *elm_spinner_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_min_max_set(double min, double max);
+EOAPI void elm_obj_spinner_min_max_set(double min, double max);
 
 /**
  * @brief Control the minimum and maximum values for the spinner.
@@ -55,7 +55,7 @@ EOAPI void  elm_obj_spinner_min_max_set(double min, double max);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_min_max_get(double *min, double *max);
+EOAPI void elm_obj_spinner_min_max_get(double *min, double *max);
 
 /**
  * @brief Control the step used to increment or decrement the spinner value.
@@ -73,7 +73,7 @@ EOAPI void  elm_obj_spinner_min_max_get(double *min, double *max);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_step_set(double step);
+EOAPI void elm_obj_spinner_step_set(double step);
 
 /**
  * @brief Control the step used to increment or decrement the spinner value.
@@ -91,7 +91,7 @@ EOAPI void  elm_obj_spinner_step_set(double step);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI double  elm_obj_spinner_step_get(void);
+EOAPI double elm_obj_spinner_step_get(void);
 
 /**
  * @brief Control whether the spinner should wrap when it reaches its minimum
@@ -118,7 +118,7 @@ EOAPI double  elm_obj_spinner_step_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_wrap_set(Eina_Bool wrap);
+EOAPI void elm_obj_spinner_wrap_set(Eina_Bool wrap);
 
 /**
  * @brief Control whether the spinner should wrap when it reaches its minimum
@@ -145,7 +145,7 @@ EOAPI void  elm_obj_spinner_wrap_set(Eina_Bool wrap);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI Eina_Bool  elm_obj_spinner_wrap_get(void);
+EOAPI Eina_Bool elm_obj_spinner_wrap_get(void);
 
 /**
  * @brief Control the interval on time updates for an user mouse button hold on
@@ -168,7 +168,7 @@ EOAPI Eina_Bool  elm_obj_spinner_wrap_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_interval_set(double interval);
+EOAPI void elm_obj_spinner_interval_set(double interval);
 
 /**
  * @brief Control the interval on time updates for an user mouse button hold on
@@ -191,7 +191,7 @@ EOAPI void  elm_obj_spinner_interval_set(double interval);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI double  elm_obj_spinner_interval_get(void);
+EOAPI double elm_obj_spinner_interval_get(void);
 
 /**
  * @brief Control the round value for rounding
@@ -202,7 +202,7 @@ EOAPI double  elm_obj_spinner_interval_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_round_set(int rnd);
+EOAPI void elm_obj_spinner_round_set(int rnd);
 
 /**
  * @brief Control the round value for rounding
@@ -213,7 +213,7 @@ EOAPI void  elm_obj_spinner_round_set(int rnd);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI int  elm_obj_spinner_round_get(void);
+EOAPI int elm_obj_spinner_round_get(void);
 
 /**
  * @brief Control whether the spinner can be directly edited by the user or
@@ -231,7 +231,7 @@ EOAPI int  elm_obj_spinner_round_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_editable_set(Eina_Bool editable);
+EOAPI void elm_obj_spinner_editable_set(Eina_Bool editable);
 
 /**
  * @brief Control whether the spinner can be directly edited by the user or
@@ -249,7 +249,7 @@ EOAPI void  elm_obj_spinner_editable_set(Eina_Bool editable);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI Eina_Bool  elm_obj_spinner_editable_get(void);
+EOAPI Eina_Bool elm_obj_spinner_editable_get(void);
 
 /**
  * @brief Control the base for rounding
@@ -272,7 +272,7 @@ EOAPI Eina_Bool  elm_obj_spinner_editable_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_base_set(double base);
+EOAPI void elm_obj_spinner_base_set(double base);
 
 /**
  * @brief Control the base for rounding
@@ -295,7 +295,7 @@ EOAPI void  elm_obj_spinner_base_set(double base);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI double  elm_obj_spinner_base_get(void);
+EOAPI double elm_obj_spinner_base_get(void);
 
 /**
  * @brief Control the value the spinner displays.
@@ -310,7 +310,7 @@ EOAPI double  elm_obj_spinner_base_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_value_set(double val);
+EOAPI void elm_obj_spinner_value_set(double val);
 
 /**
  * @brief Control the value the spinner displays.
@@ -325,7 +325,7 @@ EOAPI void  elm_obj_spinner_value_set(double val);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI double  elm_obj_spinner_value_get(void);
+EOAPI double elm_obj_spinner_value_get(void);
 
 /**
  * @brief Control the format string of the displayed label.
@@ -344,7 +344,7 @@ EOAPI double  elm_obj_spinner_value_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_label_format_set(const char *fmt);
+EOAPI void elm_obj_spinner_label_format_set(const char *fmt);
 
 /**
  * @brief Control the format string of the displayed label.
@@ -363,7 +363,7 @@ EOAPI void  elm_obj_spinner_label_format_set(const char *fmt);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI const char * elm_obj_spinner_label_format_get(void);
+EOAPI const char *elm_obj_spinner_label_format_get(void);
 
 /**
  * @brief Control special string to display in the place of the numerical
@@ -379,14 +379,12 @@ EOAPI const char * elm_obj_spinner_label_format_get(void);
  *
  * @ingroup Elm_Spinner
  */
-EOAPI void  elm_obj_spinner_special_value_add(double value, const char *label);
+EOAPI void elm_obj_spinner_special_value_add(double value, const char *label);
 
 EOAPI extern const Eo_Event_Description _ELM_SPINNER_EVENT_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_SPINNER_EVENT_DELAY_CHANGED;
 EOAPI extern const Eo_Event_Description _ELM_SPINNER_EVENT_SPINNER_DRAG_START;
 EOAPI extern const Eo_Event_Description _ELM_SPINNER_EVENT_SPINNER_DRAG_STOP;
-EOAPI extern const Eo_Event_Description _ELM_SPINNER_EVENT_LANGUAGE_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_SPINNER_EVENT_ACCESS_CHANGED;
 
 /**
  * No description
@@ -408,14 +406,4 @@ EOAPI extern const Eo_Event_Description _ELM_SPINNER_EVENT_ACCESS_CHANGED;
  */
 #define ELM_SPINNER_EVENT_SPINNER_DRAG_STOP (&(_ELM_SPINNER_EVENT_SPINNER_DRAG_STOP))
 
-/**
- * No description
- */
-#define ELM_SPINNER_EVENT_LANGUAGE_CHANGED (&(_ELM_SPINNER_EVENT_LANGUAGE_CHANGED))
-
-/**
- * No description
- */
-#define ELM_SPINNER_EVENT_ACCESS_CHANGED (&(_ELM_SPINNER_EVENT_ACCESS_CHANGED))
-
 #endif
