@@ -197,7 +197,7 @@ EAPI const Eo_Class *elm_win_class_get(void) EINA_CONST;
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_keyboard_win_set(Eina_Bool is_keyboard);
+EOAPI void elm_obj_win_keyboard_win_set(Eina_Bool is_keyboard);
 
 /**
  * @brief Get whether the window is a keyboard.
@@ -206,7 +206,7 @@ EOAPI void  elm_obj_win_keyboard_win_set(Eina_Bool is_keyboard);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_keyboard_win_get(void);
+EOAPI Eina_Bool elm_obj_win_keyboard_win_get(void);
 
 /**
  * @brief Set the window's autodel state.
@@ -227,7 +227,7 @@ EOAPI Eina_Bool  elm_obj_win_keyboard_win_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_autodel_set(Eina_Bool autodel);
+EOAPI void elm_obj_win_autodel_set(Eina_Bool autodel);
 
 /**
  * @brief Get the window's autodel state.
@@ -236,7 +236,7 @@ EOAPI void  elm_obj_win_autodel_set(Eina_Bool autodel);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_autodel_get(void);
+EOAPI Eina_Bool elm_obj_win_autodel_get(void);
 
 /**
  * @brief Window's autohide state.
@@ -257,7 +257,7 @@ EOAPI Eina_Bool  elm_obj_win_autodel_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_autohide_set(Eina_Bool autohide);
+EOAPI void elm_obj_win_autohide_set(Eina_Bool autohide);
 
 /**
  * @brief Window's autohide state.
@@ -277,7 +277,7 @@ EOAPI void  elm_obj_win_autohide_set(Eina_Bool autohide);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_autohide_get(void);
+EOAPI Eina_Bool elm_obj_win_autohide_get(void);
 
 /**
  * @brief Set the override state of a window.
@@ -296,7 +296,7 @@ EOAPI Eina_Bool  elm_obj_win_autohide_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_override_set(Eina_Bool override);
+EOAPI void elm_obj_win_override_set(Eina_Bool override);
 
 /**
  * @brief Get the override state of a window.
@@ -305,7 +305,7 @@ EOAPI void  elm_obj_win_override_set(Eina_Bool override);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_override_get(void);
+EOAPI Eina_Bool elm_obj_win_override_get(void);
 
 /**
  * @brief Set the iconified state of a window.
@@ -314,7 +314,7 @@ EOAPI Eina_Bool  elm_obj_win_override_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_iconified_set(Eina_Bool iconified);
+EOAPI void elm_obj_win_iconified_set(Eina_Bool iconified);
 
 /**
  * @brief Get the iconified state of a window.
@@ -323,7 +323,7 @@ EOAPI void  elm_obj_win_iconified_set(Eina_Bool iconified);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_iconified_get(void);
+EOAPI Eina_Bool elm_obj_win_iconified_get(void);
 
 /**
  * @brief Set the array of available window rotations.
@@ -338,7 +338,7 @@ EOAPI Eina_Bool  elm_obj_win_iconified_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_wm_available_rotations_set(const int *rotations, unsigned int count);
+EOAPI void elm_obj_win_wm_available_rotations_set(const int *rotations, unsigned int count);
 
 /**
  * @brief Get the array of available window rotations.
@@ -352,7 +352,7 @@ EOAPI void  elm_obj_win_wm_available_rotations_set(const int *rotations, unsigne
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_wm_available_rotations_get(int **rotations, unsigned int *count);
+EOAPI Eina_Bool elm_obj_win_wm_available_rotations_get(int **rotations, unsigned int *count);
 
 /**
  * @brief Set which zone this quickpanel should appear in.
@@ -361,7 +361,7 @@ EOAPI Eina_Bool  elm_obj_win_wm_available_rotations_get(int **rotations, unsigne
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_quickpanel_zone_set(int zone);
+EOAPI void elm_obj_win_quickpanel_zone_set(int zone);
 
 /**
  * @brief Get which zone this quickpanel should appear in.
@@ -370,7 +370,7 @@ EOAPI void  elm_obj_win_quickpanel_zone_set(int zone);
  *
  * @ingroup Elm_Win
  */
-EOAPI int  elm_obj_win_quickpanel_zone_get(void);
+EOAPI int elm_obj_win_quickpanel_zone_get(void);
 
 /**
  * @brief Set the maximized state of a window.
@@ -379,7 +379,7 @@ EOAPI int  elm_obj_win_quickpanel_zone_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_maximized_set(Eina_Bool maximized);
+EOAPI void elm_obj_win_maximized_set(Eina_Bool maximized);
 
 /**
  * @brief Get the maximized state of a window.
@@ -388,7 +388,7 @@ EOAPI void  elm_obj_win_maximized_set(Eina_Bool maximized);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_maximized_get(void);
+EOAPI Eina_Bool elm_obj_win_maximized_get(void);
 
 /**
  * @brief Set the modal state of a window.
@@ -397,7 +397,7 @@ EOAPI Eina_Bool  elm_obj_win_maximized_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_modal_set(Eina_Bool modal);
+EOAPI void elm_obj_win_modal_set(Eina_Bool modal);
 
 /**
  * @brief Get the modal state of a window.
@@ -406,7 +406,7 @@ EOAPI void  elm_obj_win_modal_set(Eina_Bool modal);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_modal_get(void);
+EOAPI Eina_Bool elm_obj_win_modal_get(void);
 
 /**
  * @brief Set the icon name of the window.
@@ -415,7 +415,7 @@ EOAPI Eina_Bool  elm_obj_win_modal_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_icon_name_set(const char *icon_name);
+EOAPI void elm_obj_win_icon_name_set(const char *icon_name);
 
 /**
  * @brief Get the icon name of the window.
@@ -428,7 +428,7 @@ EOAPI void  elm_obj_win_icon_name_set(const char *icon_name);
  *
  * @ingroup Elm_Win
  */
-EOAPI const char * elm_obj_win_icon_name_get(void);
+EOAPI const char *elm_obj_win_icon_name_get(void);
 
 /**
  * @brief Set the withdrawn state of a window.
@@ -437,7 +437,7 @@ EOAPI const char * elm_obj_win_icon_name_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_withdrawn_set(Eina_Bool withdrawn);
+EOAPI void elm_obj_win_withdrawn_set(Eina_Bool withdrawn);
 
 /**
  * @brief Get the withdrawn state of a window.
@@ -446,7 +446,7 @@ EOAPI void  elm_obj_win_withdrawn_set(Eina_Bool withdrawn);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_withdrawn_get(void);
+EOAPI Eina_Bool elm_obj_win_withdrawn_get(void);
 
 /**
  * @brief Set the role of the window.
@@ -455,7 +455,7 @@ EOAPI Eina_Bool  elm_obj_win_withdrawn_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_role_set(const char *role);
+EOAPI void elm_obj_win_role_set(const char *role);
 
 /**
  * @brief Get the role of the window.
@@ -467,7 +467,7 @@ EOAPI void  elm_obj_win_role_set(const char *role);
  *
  * @ingroup Elm_Win
  */
-EOAPI const char * elm_obj_win_role_get(void);
+EOAPI const char *elm_obj_win_role_get(void);
 
 /**
  * @brief Set the window stepping used with sizing calculation.
@@ -481,7 +481,7 @@ EOAPI const char * elm_obj_win_role_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_size_step_set(int w, int h);
+EOAPI void elm_obj_win_size_step_set(int w, int h);
 
 /**
  * @brief Get the stepping of a window.
@@ -493,7 +493,7 @@ EOAPI void  elm_obj_win_size_step_set(int w, int h);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_size_step_get(int *w, int *h);
+EOAPI void elm_obj_win_size_step_get(int *w, int *h);
 
 /**
  * @brief Set the style for the focus highlight on this window.
@@ -505,7 +505,7 @@ EOAPI void  elm_obj_win_size_step_get(int *w, int *h);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_focus_highlight_style_set(const char *style);
+EOAPI void elm_obj_win_focus_highlight_style_set(const char *style);
 
 /**
  * @brief Get the style set for the focus highlight object.
@@ -514,7 +514,7 @@ EOAPI void  elm_obj_win_focus_highlight_style_set(const char *style);
  *
  * @ingroup Elm_Win
  */
-EOAPI const char * elm_obj_win_focus_highlight_style_get(void);
+EOAPI const char *elm_obj_win_focus_highlight_style_get(void);
 
 /**
  * @brief Set the borderless state of a window.
@@ -526,7 +526,7 @@ EOAPI const char * elm_obj_win_focus_highlight_style_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_borderless_set(Eina_Bool borderless);
+EOAPI void elm_obj_win_borderless_set(Eina_Bool borderless);
 
 /**
  * @brief Get the borderless state of a window.
@@ -535,7 +535,7 @@ EOAPI void  elm_obj_win_borderless_set(Eina_Bool borderless);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_borderless_get(void);
+EOAPI Eina_Bool elm_obj_win_borderless_get(void);
 
 /**
  * @brief Constrain the maximum width and height of a window to the width and
@@ -548,7 +548,7 @@ EOAPI Eina_Bool  elm_obj_win_borderless_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_screen_constrain_set(Eina_Bool constrain);
+EOAPI void elm_obj_win_screen_constrain_set(Eina_Bool constrain);
 
 /**
  * @brief Get the constraints on the maximum width and height of a window
@@ -561,7 +561,7 @@ EOAPI void  elm_obj_win_screen_constrain_set(Eina_Bool constrain);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_screen_constrain_get(void);
+EOAPI Eina_Bool elm_obj_win_screen_constrain_get(void);
 
 /**
  * @brief Set the array of available profiles to a window.
@@ -573,7 +573,7 @@ EOAPI Eina_Bool  elm_obj_win_screen_constrain_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_available_profiles_set(const char **profiles, unsigned int count);
+EOAPI void elm_obj_win_available_profiles_set(const char **profiles, unsigned int count);
 
 /**
  * @brief Get the array of available profiles of a window.
@@ -585,7 +585,7 @@ EOAPI void  elm_obj_win_available_profiles_set(const char **profiles, unsigned i
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_available_profiles_get(char ***profiles, unsigned int *count);
+EOAPI Eina_Bool elm_obj_win_available_profiles_get(char ***profiles, unsigned int *count);
 
 /**
  * @brief Set the enabled status for the focus highlight in a window.
@@ -597,7 +597,7 @@ EOAPI Eina_Bool  elm_obj_win_available_profiles_get(char ***profiles, unsigned i
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_focus_highlight_enabled_set(Eina_Bool enabled);
+EOAPI void elm_obj_win_focus_highlight_enabled_set(Eina_Bool enabled);
 
 /**
  * @brief Get the enabled value of the focus highlight for this window.
@@ -606,7 +606,7 @@ EOAPI void  elm_obj_win_focus_highlight_enabled_set(Eina_Bool enabled);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_focus_highlight_enabled_get(void);
+EOAPI Eina_Bool elm_obj_win_focus_highlight_enabled_get(void);
 
 /**
  * @brief Set the title of the window.
@@ -615,7 +615,7 @@ EOAPI Eina_Bool  elm_obj_win_focus_highlight_enabled_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_title_set(const char *title);
+EOAPI void elm_obj_win_title_set(const char *title);
 
 /**
  * @brief Get the title of the window.
@@ -627,7 +627,7 @@ EOAPI void  elm_obj_win_title_set(const char *title);
  *
  * @ingroup Elm_Win
  */
-EOAPI const char * elm_obj_win_title_get(void);
+EOAPI const char *elm_obj_win_title_get(void);
 
 /**
  * @brief Set the alpha channel state of a window.
@@ -649,7 +649,7 @@ EOAPI const char * elm_obj_win_title_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_alpha_set(Eina_Bool alpha);
+EOAPI void elm_obj_win_alpha_set(Eina_Bool alpha);
 
 /**
  * @brief Get the alpha channel state of a window.
@@ -658,7 +658,7 @@ EOAPI void  elm_obj_win_alpha_set(Eina_Bool alpha);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_alpha_get(void);
+EOAPI Eina_Bool elm_obj_win_alpha_get(void);
 
 /**
  * @brief Set the urgent state of a window.
@@ -667,7 +667,7 @@ EOAPI Eina_Bool  elm_obj_win_alpha_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_urgent_set(Eina_Bool urgent);
+EOAPI void elm_obj_win_urgent_set(Eina_Bool urgent);
 
 /**
  * @brief Get the urgent state of a window.
@@ -676,7 +676,7 @@ EOAPI void  elm_obj_win_urgent_set(Eina_Bool urgent);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_urgent_get(void);
+EOAPI Eina_Bool elm_obj_win_urgent_get(void);
 
 /**
  * @brief Set the rotation of the window.
@@ -693,7 +693,7 @@ EOAPI Eina_Bool  elm_obj_win_urgent_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_rotation_set(int rotation);
+EOAPI void elm_obj_win_rotation_set(int rotation);
 
 /**
  * @brief Get the rotation of the window.
@@ -702,7 +702,7 @@ EOAPI void  elm_obj_win_rotation_set(int rotation);
  *
  * @ingroup Elm_Win
  */
-EOAPI int  elm_obj_win_rotation_get(void);
+EOAPI int elm_obj_win_rotation_get(void);
 
 /**
  * @brief Set a window object's icon.
@@ -718,7 +718,7 @@ EOAPI int  elm_obj_win_rotation_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_icon_object_set(Evas_Object *icon);
+EOAPI void elm_obj_win_icon_object_set(Evas_Object *icon);
 
 /**
  * @brief Get the icon object used for the window.
@@ -730,7 +730,7 @@ EOAPI void  elm_obj_win_icon_object_set(Evas_Object *icon);
  *
  * @ingroup Elm_Win
  */
-EOAPI const Evas_Object * elm_obj_win_icon_object_get(void);
+EOAPI const Evas_Object *elm_obj_win_icon_object_get(void);
 
 /**
  * @brief Set the minor priority of a quickpanel window.
@@ -739,7 +739,7 @@ EOAPI const Evas_Object * elm_obj_win_icon_object_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_quickpanel_priority_minor_set(int priority);
+EOAPI void elm_obj_win_quickpanel_priority_minor_set(int priority);
 
 /**
  * @brief Get the minor priority of a quickpanel window.
@@ -748,7 +748,7 @@ EOAPI void  elm_obj_win_quickpanel_priority_minor_set(int priority);
  *
  * @ingroup Elm_Win
  */
-EOAPI int  elm_obj_win_quickpanel_priority_minor_get(void);
+EOAPI int elm_obj_win_quickpanel_priority_minor_get(void);
 
 /**
  * @brief Set the sticky state of the window.
@@ -760,7 +760,7 @@ EOAPI int  elm_obj_win_quickpanel_priority_minor_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_sticky_set(Eina_Bool sticky);
+EOAPI void elm_obj_win_sticky_set(Eina_Bool sticky);
 
 /**
  * @brief Get the sticky state of the window.
@@ -769,7 +769,7 @@ EOAPI void  elm_obj_win_sticky_set(Eina_Bool sticky);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_sticky_get(void);
+EOAPI Eina_Bool elm_obj_win_sticky_get(void);
 
 /**
  * @brief Sets the keyboard mode of the window.
@@ -778,7 +778,7 @@ EOAPI Eina_Bool  elm_obj_win_sticky_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_keyboard_mode_set(Elm_Win_Keyboard_Mode mode);
+EOAPI void elm_obj_win_keyboard_mode_set(Elm_Win_Keyboard_Mode mode);
 
 /**
  * @brief Get the keyboard mode of the window.
@@ -787,7 +787,7 @@ EOAPI void  elm_obj_win_keyboard_mode_set(Elm_Win_Keyboard_Mode mode);
  *
  * @ingroup Elm_Win
  */
-EOAPI Elm_Win_Keyboard_Mode  elm_obj_win_keyboard_mode_get(void);
+EOAPI Elm_Win_Keyboard_Mode elm_obj_win_keyboard_mode_get(void);
 
 /**
  * @brief Set the animate status for the focus highlight for this window.
@@ -799,7 +799,7 @@ EOAPI Elm_Win_Keyboard_Mode  elm_obj_win_keyboard_mode_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_focus_highlight_animate_set(Eina_Bool animate);
+EOAPI void elm_obj_win_focus_highlight_animate_set(Eina_Bool animate);
 
 /**
  * @brief Get the animate value of the focus highlight for this window.
@@ -808,7 +808,7 @@ EOAPI void  elm_obj_win_focus_highlight_animate_set(Eina_Bool animate);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_focus_highlight_animate_get(void);
+EOAPI Eina_Bool elm_obj_win_focus_highlight_animate_get(void);
 
 /**
  * @brief Set the aspect ratio of a window.
@@ -818,7 +818,7 @@ EOAPI Eina_Bool  elm_obj_win_focus_highlight_animate_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_aspect_set(double aspect);
+EOAPI void elm_obj_win_aspect_set(double aspect);
 
 /**
  * @brief Get the aspect ratio of a window.
@@ -828,7 +828,7 @@ EOAPI void  elm_obj_win_aspect_set(double aspect);
  *
  * @ingroup Elm_Win
  */
-EOAPI double  elm_obj_win_aspect_get(void);
+EOAPI double elm_obj_win_aspect_get(void);
 
 /**
  * @brief Set the major priority of a quickpanel window.
@@ -837,7 +837,7 @@ EOAPI double  elm_obj_win_aspect_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_quickpanel_priority_major_set(int priority);
+EOAPI void elm_obj_win_quickpanel_priority_major_set(int priority);
 
 /**
  * @brief Get the major priority of a quickpanel window.
@@ -846,7 +846,7 @@ EOAPI void  elm_obj_win_quickpanel_priority_major_set(int priority);
  *
  * @ingroup Elm_Win
  */
-EOAPI int  elm_obj_win_quickpanel_priority_major_get(void);
+EOAPI int elm_obj_win_quickpanel_priority_major_get(void);
 
 /**
  * @brief Sets the indicator opacity mode of the window.
@@ -855,7 +855,7 @@ EOAPI int  elm_obj_win_quickpanel_priority_major_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_indicator_opacity_set(Elm_Win_Indicator_Opacity_Mode mode);
+EOAPI void elm_obj_win_indicator_opacity_set(Elm_Win_Indicator_Opacity_Mode mode);
 
 /**
  * @brief Get the indicator opacity mode of the window.
@@ -864,7 +864,7 @@ EOAPI void  elm_obj_win_indicator_opacity_set(Elm_Win_Indicator_Opacity_Mode mod
  *
  * @ingroup Elm_Win
  */
-EOAPI Elm_Win_Indicator_Opacity_Mode  elm_obj_win_indicator_opacity_get(void);
+EOAPI Elm_Win_Indicator_Opacity_Mode elm_obj_win_indicator_opacity_get(void);
 
 /**
  * @brief Set the demand_attention state of a window.
@@ -873,7 +873,7 @@ EOAPI Elm_Win_Indicator_Opacity_Mode  elm_obj_win_indicator_opacity_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_demand_attention_set(Eina_Bool demand_attention);
+EOAPI void elm_obj_win_demand_attention_set(Eina_Bool demand_attention);
 
 /**
  * @brief Get the demand_attention state of a window.
@@ -882,7 +882,7 @@ EOAPI void  elm_obj_win_demand_attention_set(Eina_Bool demand_attention);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_demand_attention_get(void);
+EOAPI Eina_Bool elm_obj_win_demand_attention_get(void);
 
 /**
  * @brief Set the preferred rotation value.
@@ -897,7 +897,7 @@ EOAPI Eina_Bool  elm_obj_win_demand_attention_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_wm_preferred_rotation_set(int rotation);
+EOAPI void elm_obj_win_wm_preferred_rotation_set(int rotation);
 
 /**
  * @brief Get the preferred rotation value.
@@ -911,7 +911,7 @@ EOAPI void  elm_obj_win_wm_preferred_rotation_set(int rotation);
  *
  * @ingroup Elm_Win
  */
-EOAPI int  elm_obj_win_wm_preferred_rotation_get(void);
+EOAPI int elm_obj_win_wm_preferred_rotation_get(void);
 
 /**
  * @brief Set the layer of the window.
@@ -927,7 +927,7 @@ EOAPI int  elm_obj_win_wm_preferred_rotation_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_layer_set(int layer);
+EOAPI void elm_obj_win_layer_set(int layer);
 
 /**
  * @brief Get the layer of the window.
@@ -936,7 +936,7 @@ EOAPI void  elm_obj_win_layer_set(int layer);
  *
  * @ingroup Elm_Win
  */
-EOAPI int  elm_obj_win_layer_get(void);
+EOAPI int elm_obj_win_layer_get(void);
 
 /**
  * @brief Set the profile of a window.
@@ -947,7 +947,7 @@ EOAPI int  elm_obj_win_layer_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_profile_set(const char *profile);
+EOAPI void elm_obj_win_profile_set(const char *profile);
 
 /**
  * @brief Get the profile of a window.
@@ -958,7 +958,7 @@ EOAPI void  elm_obj_win_profile_set(const char *profile);
  *
  * @ingroup Elm_Win
  */
-EOAPI const char * elm_obj_win_profile_get(void);
+EOAPI const char *elm_obj_win_profile_get(void);
 
 /**
  * @brief Set the shaped state of a window.
@@ -974,7 +974,7 @@ EOAPI const char * elm_obj_win_profile_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_shaped_set(Eina_Bool shaped);
+EOAPI void elm_obj_win_shaped_set(Eina_Bool shaped);
 
 /**
  * @brief Get the shaped state of a window.
@@ -983,7 +983,7 @@ EOAPI void  elm_obj_win_shaped_set(Eina_Bool shaped);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_shaped_get(void);
+EOAPI Eina_Bool elm_obj_win_shaped_get(void);
 
 /**
  * @brief Set the fullscreen state of a window.
@@ -992,7 +992,7 @@ EOAPI Eina_Bool  elm_obj_win_shaped_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_fullscreen_set(Eina_Bool fullscreen);
+EOAPI void elm_obj_win_fullscreen_set(Eina_Bool fullscreen);
 
 /**
  * @brief Get the fullscreen state of a window.
@@ -1001,7 +1001,7 @@ EOAPI void  elm_obj_win_fullscreen_set(Eina_Bool fullscreen);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_fullscreen_get(void);
+EOAPI Eina_Bool elm_obj_win_fullscreen_get(void);
 
 /**
  * @brief Set the manual rotation done mode.
@@ -1017,7 +1017,7 @@ EOAPI Eina_Bool  elm_obj_win_fullscreen_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_wm_manual_rotation_done_set(Eina_Bool set);
+EOAPI void elm_obj_win_wm_manual_rotation_done_set(Eina_Bool set);
 
 /**
  * @brief Get the state of manual rotation done mode.
@@ -1030,7 +1030,7 @@ EOAPI void  elm_obj_win_wm_manual_rotation_done_set(Eina_Bool set);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_wm_manual_rotation_done_get(void);
+EOAPI Eina_Bool elm_obj_win_wm_manual_rotation_done_get(void);
 
 /**
  * @brief Sets the indicator mode of the window.
@@ -1039,7 +1039,7 @@ EOAPI Eina_Bool  elm_obj_win_wm_manual_rotation_done_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_indicator_mode_set(Elm_Win_Indicator_Mode mode);
+EOAPI void elm_obj_win_indicator_mode_set(Elm_Win_Indicator_Mode mode);
 
 /**
  * @brief Get the indicator mode of the window.
@@ -1048,7 +1048,7 @@ EOAPI void  elm_obj_win_indicator_mode_set(Elm_Win_Indicator_Mode mode);
  *
  * @ingroup Elm_Win
  */
-EOAPI Elm_Win_Indicator_Mode  elm_obj_win_indicator_mode_get(void);
+EOAPI Elm_Win_Indicator_Mode elm_obj_win_indicator_mode_get(void);
 
 /**
  * @brief Set if this window is an illume conformant window.
@@ -1057,7 +1057,7 @@ EOAPI Elm_Win_Indicator_Mode  elm_obj_win_indicator_mode_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_conformant_set(Eina_Bool conformant);
+EOAPI void elm_obj_win_conformant_set(Eina_Bool conformant);
 
 /**
  * @brief Get if this window is an illume conformant window.
@@ -1066,7 +1066,7 @@ EOAPI void  elm_obj_win_conformant_set(Eina_Bool conformant);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_conformant_get(void);
+EOAPI Eina_Bool elm_obj_win_conformant_get(void);
 
 /**
  * @brief Set the base window size used with stepping calculation
@@ -1080,7 +1080,7 @@ EOAPI Eina_Bool  elm_obj_win_conformant_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_size_base_set(int w, int h);
+EOAPI void elm_obj_win_size_base_set(int w, int h);
 
 /**
  * @brief Get the base size of a window.
@@ -1092,7 +1092,7 @@ EOAPI void  elm_obj_win_size_base_set(int w, int h);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_size_base_get(int *w, int *h);
+EOAPI void elm_obj_win_size_base_get(int *w, int *h);
 
 /**
  * @brief Set a window to be an illume quickpanel window.
@@ -1103,7 +1103,7 @@ EOAPI void  elm_obj_win_size_base_get(int *w, int *h);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_quickpanel_set(Eina_Bool quickpanel);
+EOAPI void elm_obj_win_quickpanel_set(Eina_Bool quickpanel);
 
 /**
  * @brief Get if this window is a quickpanel or not.
@@ -1112,7 +1112,7 @@ EOAPI void  elm_obj_win_quickpanel_set(Eina_Bool quickpanel);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_quickpanel_get(void);
+EOAPI Eina_Bool elm_obj_win_quickpanel_get(void);
 
 /**
  * @brief Rotates the window and resizes it.
@@ -1125,7 +1125,7 @@ EOAPI Eina_Bool  elm_obj_win_quickpanel_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_rotation_with_resize_set(int rotation);
+EOAPI void elm_obj_win_rotation_with_resize_set(int rotation);
 
 /**
  * @brief Set the window to be skipped by keyboard focus.
@@ -1147,7 +1147,7 @@ EOAPI void  elm_obj_win_rotation_with_resize_set(int rotation);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_prop_focus_skip_set(Eina_Bool skip);
+EOAPI void elm_obj_win_prop_focus_skip_set(Eina_Bool skip);
 
 /**
  * @brief Get the screen position of a window.
@@ -1157,7 +1157,7 @@ EOAPI void  elm_obj_win_prop_focus_skip_set(Eina_Bool skip);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_screen_position_get(int *x, int *y);
+EOAPI void elm_obj_win_screen_position_get(int *x, int *y);
 
 /**
  * @brief Query whether window manager supports window rotation or not.
@@ -1174,19 +1174,19 @@ EOAPI void  elm_obj_win_screen_position_get(int *x, int *y);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_wm_rotation_supported_get(void);
+EOAPI Eina_Bool elm_obj_win_wm_rotation_supported_get(void);
 
 /** Get the Ecore_X_Window of an Evas_Object.
  *
  * @ingroup Elm_Win
  */
-EOAPI Ecore_X_Window  elm_obj_win_xwindow_get(void);
+EOAPI Ecore_X_Window elm_obj_win_xwindow_get(void);
 
 /** Get whether a window has focus.
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_focus_get(void);
+EOAPI Eina_Bool elm_obj_win_focus_get(void);
 
 /**
  * @brief Get screen geometry details for the screen that a window is on.
@@ -1198,7 +1198,7 @@ EOAPI Eina_Bool  elm_obj_win_focus_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_screen_size_get(int *x, int *y, int *w, int *h);
+EOAPI void elm_obj_win_screen_size_get(int *x, int *y, int *w, int *h);
 
 /**
  * @brief Get the Main Menu of a window.
@@ -1207,16 +1207,38 @@ EOAPI void  elm_obj_win_screen_size_get(int *x, int *y, int *w, int *h);
  *
  * @ingroup Elm_Win
  */
-EOAPI Evas_Object * elm_obj_win_main_menu_get(void);
+EOAPI Evas_Object *elm_obj_win_main_menu_get(void);
 
 /**
- * @brief Get the Ecore_Wl_Window of an Evas_Object.
+ * @brief Get the Ecore_Wl2_Window of an Evas_Object.
  *
- * @return The Ecore_Wl_Window of @c obj.
+ * @return The Ecore_Wl2_Window of @c obj.
  *
  * @ingroup Elm_Win
  */
-EOAPI Ecore_Wl_Window * elm_obj_win_wl_window_get(void);
+EOAPI Ecore_Wl2_Window *elm_obj_win_wl_window_get(void);
+
+/**
+ * @brief Get the Ecore_Cocoa_Window of an Evas.Object.
+ *
+ * @return The Ecore_Cocoa_Window of @c obj.
+ *
+ * @since 1.17
+ *
+ * @ingroup Elm_Win
+ */
+EOAPI Ecore_Cocoa_Window *elm_obj_win_cocoa_window_get(void);
+
+/**
+ * @brief Get the Ecore_Win32_Window of an Evas_Object
+ *
+ * @return The Ecore_Win32_Window of @c obj.
+ *
+ * @since 1.17
+ *
+ * @ingroup Elm_Win
+ */
+EOAPI Ecore_Win32_Window *elm_obj_win_win32_window_get(void);
 
 /**
  * @brief Get the Ecore_Window of an Evas_Object
@@ -1230,7 +1252,7 @@ EOAPI Ecore_Wl_Window * elm_obj_win_wl_window_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI Ecore_Window  elm_obj_win_window_id_get(void);
+EOAPI Ecore_Window elm_obj_win_window_id_get(void);
 
 /**
  * @brief Get screen dpi for the screen that a window is on.
@@ -1244,7 +1266,7 @@ EOAPI Ecore_Window  elm_obj_win_window_id_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_screen_dpi_get(int *xdpi, int *ydpi);
+EOAPI void elm_obj_win_screen_dpi_get(int *xdpi, int *ydpi);
 
 /**
  * @brief Get the inlined image object handle
@@ -1259,7 +1281,7 @@ EOAPI void  elm_obj_win_screen_dpi_get(int *xdpi, int *ydpi);
  *
  * @ingroup Elm_Win
  */
-EOAPI Evas_Object * elm_obj_win_inlined_image_object_get(void);
+EOAPI Evas_Object *elm_obj_win_inlined_image_object_get(void);
 
 /**
  * @brief The window name.
@@ -1277,7 +1299,7 @@ EOAPI Evas_Object * elm_obj_win_inlined_image_object_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_name_set(const char *name);
+EOAPI void elm_obj_win_name_set(const char *name);
 
 /**
  * @brief The type of the window.
@@ -1295,7 +1317,7 @@ EOAPI void  elm_obj_win_name_set(const char *name);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_type_set(Elm_Win_Type type);
+EOAPI void elm_obj_win_type_set(Elm_Win_Type type);
 
 /**
  * @brief The type of the window.
@@ -1311,7 +1333,7 @@ EOAPI void  elm_obj_win_type_set(Elm_Win_Type type);
  *
  * @ingroup Elm_Win
  */
-EOAPI Elm_Win_Type  elm_obj_win_type_get(void);
+EOAPI Elm_Win_Type elm_obj_win_type_get(void);
 
 /**
  * @brief Set the noblank property of a window.
@@ -1328,7 +1350,7 @@ EOAPI Elm_Win_Type  elm_obj_win_type_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_noblank_set(Eina_Bool noblank);
+EOAPI void elm_obj_win_noblank_set(Eina_Bool noblank);
 
 /**
  * @brief Get the noblank property of a window.
@@ -1339,7 +1361,7 @@ EOAPI void  elm_obj_win_noblank_set(Eina_Bool noblank);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_noblank_get(void);
+EOAPI Eina_Bool elm_obj_win_noblank_get(void);
 
 /**
  * @brief Get the trap data associated with a window.
@@ -1350,7 +1372,7 @@ EOAPI Eina_Bool  elm_obj_win_noblank_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void * elm_obj_win_trap_data_get(void);
+EOAPI void *elm_obj_win_trap_data_get(void);
 
 #ifdef ELM_WIN_PROTECTED
 /**
@@ -1360,7 +1382,7 @@ EOAPI void * elm_obj_win_trap_data_get(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_fake_canvas_set(Ecore_Evas *oee);
+EOAPI void elm_obj_win_fake_canvas_set(Ecore_Evas *oee);
 #endif
 
 /**
@@ -1372,7 +1394,7 @@ EOAPI void  elm_obj_win_fake_canvas_set(Ecore_Evas *oee);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_wm_manual_rotation_done_manual(void);
+EOAPI void elm_obj_win_wm_manual_rotation_done_manual(void);
 
 /**
  * @brief Create a socket to provide the service for Plug widget.
@@ -1385,7 +1407,7 @@ EOAPI void  elm_obj_win_wm_manual_rotation_done_manual(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_socket_listen(const char *svcname, int svcnum, Eina_Bool svcsys);
+EOAPI Eina_Bool elm_obj_win_socket_listen(const char *svcname, int svcnum, Eina_Bool svcsys);
 
 /**
  * @brief Send a command to the windowing environment
@@ -1400,7 +1422,7 @@ EOAPI Eina_Bool  elm_obj_win_socket_listen(const char *svcname, int svcnum, Eina
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_illume_command_send(Elm_Illume_Command command, void *params);
+EOAPI void elm_obj_win_illume_command_send(Elm_Illume_Command command, void *params);
 
 /**
  * @brief Activate a window object.
@@ -1415,7 +1437,7 @@ EOAPI void  elm_obj_win_illume_command_send(Elm_Illume_Command command, void *pa
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_activate(void);
+EOAPI void elm_obj_win_activate(void);
 
 /**
  * @brief Add @c subobj as a resize object of window @c obj.
@@ -1443,7 +1465,7 @@ EOAPI void  elm_obj_win_activate(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_resize_object_add(Evas_Object *subobj);
+EOAPI void elm_obj_win_resize_object_add(Evas_Object *subobj);
 
 /**
  * @brief Raise a window object.
@@ -1456,7 +1478,7 @@ EOAPI void  elm_obj_win_resize_object_add(Evas_Object *subobj);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_raise(void);
+EOAPI void elm_obj_win_raise(void);
 
 /**
  * @brief Lower a window object.
@@ -1469,7 +1491,7 @@ EOAPI void  elm_obj_win_raise(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_lower(void);
+EOAPI void elm_obj_win_lower(void);
 
 /**
  * @brief Delete @c subobj as a resize object of window @c obj.
@@ -1483,7 +1505,7 @@ EOAPI void  elm_obj_win_lower(void);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_resize_object_del(Evas_Object *subobj);
+EOAPI void elm_obj_win_resize_object_del(Evas_Object *subobj);
 
 /**
  * @brief Center a window on its screen
@@ -1496,7 +1518,7 @@ EOAPI void  elm_obj_win_resize_object_del(Evas_Object *subobj);
  *
  * @ingroup Elm_Win
  */
-EOAPI void  elm_obj_win_center(Eina_Bool h, Eina_Bool v);
+EOAPI void elm_obj_win_center(Eina_Bool h, Eina_Bool v);
 
 /**
  * @brief Set keygrab value of the window
@@ -1513,7 +1535,7 @@ EOAPI void  elm_obj_win_center(Eina_Bool h, Eina_Bool v);
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_keygrab_set(const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, int proirity, Elm_Win_Keygrab_Mode grab_mode);
+EOAPI Eina_Bool elm_obj_win_keygrab_set(const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, int proirity, Elm_Win_Keygrab_Mode grab_mode);
 
 /**
  * @brief Unset keygrab value of the window
@@ -1527,7 +1549,7 @@ EOAPI Eina_Bool  elm_obj_win_keygrab_set(const char *key, Evas_Modifier_Mask mod
  *
  * @ingroup Elm_Win
  */
-EOAPI Eina_Bool  elm_obj_win_keygrab_unset(const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
+EOAPI Eina_Bool elm_obj_win_keygrab_unset(const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
 
 EOAPI extern const Eo_Event_Description _ELM_WIN_EVENT_DELETE_REQUEST;
 EOAPI extern const Eo_Event_Description _ELM_WIN_EVENT_MOVED;
